@@ -1,7 +1,7 @@
 """Base classes and utility functions for codecs."""
 
 import abc
-from typing import Callable, NamedTuple, Optional, Type, Union
+from typing import Callable, NamedTuple, Optional, Union
 
 import bpack.utils
 import bpack.descriptors
@@ -71,7 +71,7 @@ class Codec(Decoder, Encoder, abc.ABC):
 CodecType = Union[Decoder, Encoder, Codec]
 
 
-def make_codec_decorator(codec_type: Type[CodecType]):
+def make_codec_decorator(codec_type: type[CodecType]):
     """Generate a codec decorator for the input decoder class."""
 
     @bpack.utils.classdecorator
@@ -86,21 +86,21 @@ def make_codec_decorator(codec_type: Type[CodecType]):
         bpack.utils.set_new_attribute(cls, CODEC_ATTR_NAME, codec_)
 
         if isinstance(codec_, Decoder):
-            decode_func = bpack.utils.create_fn(
+            bpack.utils.add_function_to_class(
+                cls,
                 name="frombytes",
                 args=("cls", "data"),
                 body=[f"return cls.{CODEC_ATTR_NAME}.decode(data)"],
+                is_classmethod=True,
             )
-            decode_func = classmethod(decode_func)
-            bpack.utils.set_new_attribute(cls, "frombytes", decode_func)
 
         if isinstance(codec_, Encoder):
-            encode_func = bpack.utils.create_fn(
+            bpack.utils.add_function_to_class(
+                cls,
                 name="tobytes",
                 args=("self",),
                 body=[f"return self.{CODEC_ATTR_NAME}.encode(self)"],
             )
-            bpack.utils.set_new_attribute(cls, "tobytes", encode_func)
 
         return cls
 
@@ -108,7 +108,7 @@ def make_codec_decorator(codec_type: Type[CodecType]):
 
 
 def has_codec(
-    descriptor, codec_type: Optional[Type[CodecType]] = None
+    descriptor, codec_type: Optional[type[CodecType]] = None
 ) -> bool:
     """Return True if the input descriptor has a codec attached.
 
@@ -119,12 +119,12 @@ def has_codec(
     The *codec_type* parameter can be used to query for specific codec
     features:
 
-    * codec_type=None: return True for any king of codec
-    * codec_type=:class:`Decoder`: return True if the attached coded has
+    * codec_type = None: return True for any kind of codec
+    * codec_type = :class:`Decoder`: return True if the attached coded has
       decoding capabilities
-    * codec_type=:class:`Encoder`: return True if the attached coded has
+    * codec_type = :class:`Encoder`: return True if the attached coded has
       encoding capabilities
-    * codec_type=:class:`Codec`: return True if the attached coded has
+    * codec_type = :class:`Codec`: return True if the attached coded has
       both encoding and decoding capabilities
     """
     if hasattr(descriptor, CODEC_ATTR_NAME):
@@ -148,7 +148,7 @@ def get_codec(descriptor) -> CodecType:
 
 
 # TODO: remove
-def get_codec_type(descriptor) -> Type[CodecType]:
+def get_codec_type(descriptor) -> type[CodecType]:
     """Return the type of the codec attached to the input descriptor."""
     codec_ = getattr(descriptor, CODEC_ATTR_NAME, None)
     if codec_ is not None:
