@@ -88,7 +88,7 @@ def descriptor_to_dtype(descriptor) -> np.dtype:
     params = dict(params)  # numpy do not accept defaultdict
     params["itemsize"] = bpack.calcsize(descriptor)
 
-    dt = np.dtype(dict(params))
+    dt = np.dtype(params)
 
     byteorder = bpack.byteorder(descriptor).value
     if byteorder:
@@ -129,7 +129,6 @@ def _decode_converter_factory(type_):
 
 
 def _encode_converter_factory(type_):
-    converter = None
     etype = bpack.utils.effective_type(type_)
     if bpack.utils.is_enum_type(type_):
         if etype is str:
@@ -149,6 +148,9 @@ def _encode_converter_factory(type_):
             # TODO: harmonize with other backends that use 'ascii'
             return x.encode("utf-8")
 
+    else:
+        converter = None
+
     # TODO: cleanup
     # elif bpack.is_descriptor(type_):
     #     # astuple works recursively so nested descriptors have been
@@ -265,8 +267,7 @@ def _get_buffer_size(bits_per_sample: int) -> int:
     return _get_item_size(bits_per_sample + 7)
 
 
-# @COMPATIBILITY: lru_cache without parenteses requires Python > 3.7
-@functools.lru_cache()
+@functools.lru_cache
 def make_bitmask(
     bits_per_sample: int,
     dtype=None,
@@ -302,7 +303,7 @@ class BitUnpackParams(NamedTuple):
     mask: np.ndarray
 
 
-@functools.lru_cache()  # @COPMPATIBILITY with Python 3.7
+@functools.lru_cache
 def _unpackbits_params(
     nbits: int,
     bits_per_sample: int,
@@ -426,7 +427,7 @@ def unsigned_to_signed(
     return out
 
 
-@functools.lru_cache()  # @COMPATIBILITY: parenteses not needed in Python>=3.8
+@functools.lru_cache
 def make_unsigned_to_signed_lut(
     bits_per_sample: int,
     dtype=None,
@@ -444,7 +445,7 @@ def make_unsigned_to_signed_lut(
     )
 
 
-def unpackbits(
+def unpackbits(  # noqa: CCR001
     data: bytes,
     bits_per_sample: int,
     samples_per_block: Optional[int] = None,
