@@ -1,6 +1,6 @@
-"""Specific tests for the bitarray based decoder."""
+"""Specific tests for the numpy based decoder."""
 
-from typing import List, Sequence
+from collections.abc import Sequence
 
 import pytest
 
@@ -19,7 +19,7 @@ def test_decode_sequence():
     @backend.decoder
     @bpack.descriptor(baseunits=backend.Decoder.baseunits, bitorder=bitorder)
     class Record:
-        field_1: List[int] = bpack.field(size=size, repeat=repeat)
+        field_1: list[int] = bpack.field(size=size, repeat=repeat)
         field_2: Sequence[int] = bpack.field(size=size, repeat=repeat)
 
     ref_record = Record([3, 3], (4, 4))
@@ -28,7 +28,7 @@ def test_decode_sequence():
     assert list(record.field_2) == list(ref_record.field_2)
 
     for field, sequence_type in zip(
-        bpack.fields(Record), (List[int], Sequence[int])
+        bpack.fields(Record), (list[int], Sequence[int])
     ):
         assert field.type == sequence_type
 
