@@ -2,13 +2,17 @@
 
 import dataclasses
 import collections.abc
-from typing import List
 
 import pytest
 
 import bpack
-from bpack import EBaseUnits, EByteOrder, EBitOrder
-from bpack.descriptors import BinFieldDescriptor, METADATA_KEY
+from bpack import EBaseUnits, EByteOrder, EBitOrder, T
+from bpack.descriptors import (
+    METADATA_KEY,
+    BinFieldDescriptor,
+    flat_fields_iterator,
+    get_field_descriptor,
+)
 
 
 def test_is_descriptor():
@@ -82,7 +86,7 @@ def test_calcsize():
     class Record:
         field_1: int = bpack.field(size=4, default=0)
         field_2: float = bpack.field(size=8, default=1 / 3)
-        field_3: List[int] = bpack.field(size=1, default=0, repeat=4)
+        field_3: list[int] = bpack.field(size=1, default=0, repeat=4)
 
     assert bpack.baseunits(Record) is EBaseUnits.BYTES
     assert bpack.calcsize(Record) == 16
@@ -97,7 +101,7 @@ def test_calcsize():
         field_1: int = bpack.field(size=4, default=0)
         field_2: float = bpack.field(size=16, default=1 / 3)
         field_3: int = bpack.field(size=4, default=3)
-        field_4: List[int] = bpack.field(size=4, default=0, repeat=2)
+        field_4: list[int] = bpack.field(size=4, default=0, repeat=2)
 
     assert bpack.baseunits(Record) is EBaseUnits.BITS
     assert bpack.calcsize(Record) == 4 * 8
@@ -426,9 +430,10 @@ def test_asdict():
         field_2: float = bpack.field(size=4, default=0.1)
 
     record = Record()
-    assert bpack.asdict(record) == dict(
-        field_1=record.field_1, field_2=record.field_2
-    )
+    assert bpack.asdict(record) == {
+        "field_1": record.field_1,
+        "field_2": record.field_2,
+    }
 
 
 def test_astuple():
@@ -450,3 +455,33 @@ def test_astuple():
     assert bpack.astuple(record) == values
     assert type(bpack.astuple(record)) is tuple
     assert type(bpack.astuple(record, tuple_factory=list)) is list
+
+
+def test_flat_fields_iterator():
+    @bpack.descriptor(baseunits=EBaseUnits.BITS, size=8)
+    class Record:
+        x: T["u3"] = 0  # noqa: F821
+        y: T["u3"] = bpack.field(offset=4, default=3)  # noqa: F821
+
+    @bpack.descriptor(baseunits=EBaseUnits.BITS)
+    class NestedRecord:
+        a: T["u7"] = 32  # noqa: F821
+        b: Record = bpack.field(default_factory=Record, offset=8)
+        c: T["f16"] = -9999  # noqa: F821
+
+    @bpack.descriptor(baseunits=EBaseUnits.BITS)
+    class FlatRecord:
+        a: T["u7"] = 32  # noqa: F821
+        x: T["u3"] = bpack.field(offset=8, default=0)  # noqa: F821
+        y: T["u3"] = bpack.field(offset=12, default=3)  # noqa: F821
+        c: T["f16"] = bpack.field(offset=16, default=-9999)  # noqa: F821
+
+    for firld_, ref_field in zip(
+        flat_fields_iterator(NestedRecord),
+        flat_fields_iterator(FlatRecord),
+    ):
+        assert get_field_descriptor(firld_) == get_field_descriptor(ref_field)
+        assert firld_.name == ref_field.name
+        assert firld_.type == ref_field.type
+        assert firld_.default == ref_field.default
+        assert firld_.default_factory == ref_field.default_factory
