@@ -1,7 +1,8 @@
 """Test bpack (record) descriptors."""
 
+import typing
 import dataclasses
-from typing import List, Sequence, Tuple
+from collections.abc import Sequence
 
 import pytest
 
@@ -223,21 +224,39 @@ def test_inconsistent_field_type_and_signed():
             field_2: float = bpack.field(size=8, default=1 / 3, signed=True)
 
 
-def test_repeat():
+def test_repeat_typing():
     @bpack.descriptor
     class Record:
-        field_1: List[int] = bpack.field(size=4, default=0, repeat=2)
+        field_1: typing.List[int] = bpack.field(size=4, default=0, repeat=2)
         field_2: float = bpack.field(size=8, default=1 / 3)
 
     assert bpack.calcsize(Record()) == 16
 
 
+def test_repeat():
+    @bpack.descriptor
+    class Record:
+        field_1: list[int] = bpack.field(size=4, default=0, repeat=2)
+        field_2: float = bpack.field(size=8, default=1 / 3)
+
+    assert bpack.calcsize(Record()) == 16
+
+
+def test_no_repeat_typing():
+    with pytest.raises(TypeError):
+
+        @bpack.descriptor
+        class Record:
+            field_1: typing.List[int] = bpack.field(size=4, default=0)
+            field_2: float = bpack.field(size=8, default=1 / 3)
+
+
 def test_no_repeat():
     with pytest.raises(TypeError):
 
         @bpack.descriptor
         class Record:
-            field_1: List[int] = bpack.field(size=4, default=0)
+            field_1: list[int] = bpack.field(size=4, default=0)
             field_2: float = bpack.field(size=8, default=1 / 3)
 
 
@@ -281,15 +300,37 @@ class TestExplicitSize:
                 field_1: int = bpack.field(size=4, default=0)
                 field_2: float = bpack.field(size=8, default=1 / 3, offset=12)
 
+    @staticmethod
+    def test_inconsistent_explicit_size_and_repeat_typing():
+        with pytest.raises(bpack.descriptors.DescriptorConsistencyError):
+
+            @bpack.descriptor(size=12)
+            class Record:
+                field_1: typing.List[int] = bpack.field(
+                    size=4, default=0, repeat=2
+                )
+                field_2: float = bpack.field(size=8, default=1 / 3)
+
     @staticmethod
     def test_inconsistent_explicit_size_and_repeat():
         with pytest.raises(bpack.descriptors.DescriptorConsistencyError):
 
             @bpack.descriptor(size=12)
             class Record:
-                field_1: List[int] = bpack.field(size=4, default=0, repeat=2)
+                field_1: list[int] = bpack.field(size=4, default=0, repeat=2)
                 field_2: float = bpack.field(size=8, default=1 / 3)
 
+    @staticmethod
+    def test_inconsistent_explicit_size_offset_and_repeat_typing():
+        with pytest.raises(bpack.descriptors.DescriptorConsistencyError):
+
+            @bpack.descriptor(size=20)
+            class Record:
+                field_1: int = bpack.field(size=4, default=0)
+                field_2: typing.List[float] = bpack.field(
+                    size=8, default=1 / 3, offset=8, repeat=2
+                )
+
     @staticmethod
     def test_inconsistent_explicit_size_offset_and_repeat():
         with pytest.raises(bpack.descriptors.DescriptorConsistencyError):
@@ -297,7 +338,7 @@ class TestExplicitSize:
             @bpack.descriptor(size=20)
             class Record:
                 field_1: int = bpack.field(size=4, default=0)
-                field_2: List[float] = bpack.field(
+                field_2: list[float] = bpack.field(
                     size=8, default=1 / 3, offset=8, repeat=2
                 )
 
@@ -354,31 +395,81 @@ class TestSize:
         assert bpack.calcsize(Record) == size
 
     @staticmethod
-    def test_len_with_repeat_01():
+    def test_len_with_repeat_01_typing():
         @bpack.descriptor
         class Record:
-            field_1: List[int] = bpack.field(size=4, default=0, repeat=2)
+            field_1: typing.List[int] = bpack.field(
+                size=4, default=0, repeat=2
+            )
             field_2: float = bpack.field(size=8, default=1 / 3)
 
         assert bpack.calcsize(Record) == 16
 
+    @staticmethod
+    def test_len_with_repeat_01():
+        @bpack.descriptor
+        class Record:
+            field_1: list[int] = bpack.field(size=4, default=0, repeat=2)
+            field_2: float = bpack.field(size=8, default=1 / 3)
+
+        assert bpack.calcsize(Record) == 16
+
+    @staticmethod
+    def test_len_with_repeat_02_typing():
+        @bpack.descriptor
+        class Record:
+            field_1: typing.List[int] = bpack.field(
+                size=4, default=0, repeat=2
+            )
+            field_2: typing.List[float] = bpack.field(
+                size=8, default=1 / 3, repeat=2
+            )
+
+        assert bpack.calcsize(Record) == 24
+
     @staticmethod
     def test_len_with_repeat_02():
         @bpack.descriptor
         class Record:
-            field_1: List[int] = bpack.field(size=4, default=0, repeat=2)
-            field_2: List[float] = bpack.field(size=8, default=1 / 3, repeat=2)
+            field_1: list[int] = bpack.field(size=4, default=0, repeat=2)
+            field_2: list[float] = bpack.field(size=8, default=1 / 3, repeat=2)
 
         assert bpack.calcsize(Record) == 24
 
+    @staticmethod
+    def test_len_with_repeat_and_offset_01_typing():
+        @bpack.descriptor
+        class Record:
+            field_1: typing.List[int] = bpack.field(
+                size=4, default=0, repeat=2, offset=6
+            )
+            field_2: typing.List[float] = bpack.field(
+                size=8, default=1 / 3, repeat=2
+            )
+
+        assert bpack.calcsize(Record) == 30
+
     @staticmethod
     def test_len_with_repeat_and_offset_01():
         @bpack.descriptor
         class Record:
-            field_1: List[int] = bpack.field(
+            field_1: list[int] = bpack.field(
                 size=4, default=0, repeat=2, offset=6
             )
-            field_2: List[float] = bpack.field(size=8, default=1 / 3, repeat=2)
+            field_2: list[float] = bpack.field(size=8, default=1 / 3, repeat=2)
+
+        assert bpack.calcsize(Record) == 30
+
+    @staticmethod
+    def test_len_with_repeat_and_offset_02_typing():
+        @bpack.descriptor
+        class Record:
+            field_1: typing.List[int] = bpack.field(
+                size=4, default=0, repeat=2
+            )
+            field_2: typing.List[float] = bpack.field(
+                size=8, default=1 / 3, repeat=2, offset=14
+            )
 
         assert bpack.calcsize(Record) == 30
 
@@ -386,21 +477,34 @@ class TestSize:
     def test_len_with_repeat_and_offset_02():
         @bpack.descriptor
         class Record:
-            field_1: List[int] = bpack.field(size=4, default=0, repeat=2)
-            field_2: List[float] = bpack.field(
+            field_1: list[int] = bpack.field(size=4, default=0, repeat=2)
+            field_2: list[float] = bpack.field(
                 size=8, default=1 / 3, repeat=2, offset=14
             )
 
         assert bpack.calcsize(Record) == 30
 
+    @staticmethod
+    def test_len_with_repeat_and_offset_03_typing():
+        with pytest.raises(bpack.descriptors.DescriptorConsistencyError):
+
+            @bpack.descriptor
+            class Record:
+                field_1: typing.List[int] = bpack.field(
+                    size=4, default=0, repeat=2
+                )
+                field_2: typing.List[float] = bpack.field(
+                    size=8, default=1 / 3, repeat=2, offset=6
+                )
+
     @staticmethod
     def test_len_with_repeat_and_offset_03():
         with pytest.raises(bpack.descriptors.DescriptorConsistencyError):
 
             @bpack.descriptor
             class Record:
-                field_1: List[int] = bpack.field(size=4, default=0, repeat=2)
-                field_2: List[float] = bpack.field(
+                field_1: list[int] = bpack.field(size=4, default=0, repeat=2)
+                field_2: list[float] = bpack.field(
                     size=8, default=1 / 3, repeat=2, offset=6
                 )
 
@@ -408,10 +512,18 @@ class TestSize:
 def test_sequence_type():
     @bpack.descriptor
     class Record:
-        field_1: List[int] = bpack.field(size=1, repeat=4)
+        field_1: list[int] = bpack.field(size=1, repeat=4)
 
     field_1 = bpack.fields(Record)[0]
-    assert field_1.type is List[int]
+    assert field_1.type == list[int]
+    assert bpack.calcsize(Record) == 4
+
+    @bpack.descriptor
+    class Record:
+        field_1: typing.List[int] = bpack.field(size=1, repeat=4)
+
+    field_1 = bpack.fields(Record)[0]
+    assert field_1.type is typing.List[int]
     assert bpack.calcsize(Record) == 4
 
     @bpack.descriptor
@@ -419,13 +531,19 @@ def test_sequence_type():
         field_1: Sequence[int] = bpack.field(size=1, repeat=4)
 
     field_1 = bpack.fields(Record)[0]
-    assert field_1.type is Sequence[int]
+    assert field_1.type == Sequence[int]
 
     with pytest.raises(TypeError):
 
         @bpack.descriptor
         class Record:
-            field_1: Tuple[int, int] = bpack.field(size=1, repeat=2)
+            field_1: tuple[int, int] = bpack.field(size=1, repeat=2)
+
+    with pytest.raises(TypeError):
+
+        @bpack.descriptor
+        class Record:
+            field_1: typing.Tuple[int, int] = bpack.field(size=1, repeat=2)
 
     with pytest.raises(TypeError):
 
